from mininet.net import Mininet
from mininet.topo import Topo
from mininet.cli import CLI
from mininet.node import RemoteController
from mininet.node import RemoteController, Host, OVSKernelSwitch

from mininet.link import TCLink
from argparse import ArgumentParser

# Function to parse the command line arguments
def parseOptions():

    # Create a parser object
    parser = ArgumentParser("Create a network with leaf and spine topology")

    # Add argument to the parser for nSpine, nLeaf and fanout options
    parser.add_argument('--spine', type=int, help='Number of Spine switches')
    parser.add_argument('--leaf', type=int, help='Number of Leaf switches')
    parser.add_argument('--fanout', type=int, help='Number of hosts per Lead switch')

    # Parse the command line arguments
    args = parser.parse_args()

    # Set the default values for arguments
    nSpine = 2
    nLeaf = 3
    fanout = 2

    # Change the values if passed on command line
    if args.spine:
        nSpine = args.spine

    if args.leaf:
        nLeaf = args.leaf

    if args.fanout:
        fanout = args.fanout

    # return the values
    return nSpine, nLeaf, fanout




class LeafAndSpine(Topo):
    def __init__(self, spine=2, leaf=2, fanout=2, **opts):
        "Create Leaf and Spine Topo."

        Topo.__init__(self, **opts)
        
     # This function builds a leaf and spine topology
     # Parameters passed to this function are
     #
     #    spine - Number of Spine switches
     #    leaf  - Number of Leaf switches
     #    fanout - Number of hosts per leaf switch
     #
 
 

if __name__ == '__main__':
    
 
    nSpine, nLeaf, fanout = parseOptions()

    topo = LeafAndSpine(nSpine, nLeaf, fanout)
    net = Mininet(topo, autoSetMacs=True, xterms=False, controller=RemoteController, switch=OVSKernelSwitch)
    net.addController('c', ip='127.0.0.1', port=6633)  
   
    net.start()
    
    CLI(net)
    net.stop()
